@@ -472,7 +472,7 @@ get_if_name(const char *if_text)
  *  This is necessary because capture_opts.c can't set descr (at least
  *  not without adding significant dependencies there).
  */
-const char *
+static const char *
 get_iface_description_for_interface(capture_options *capture_opts, guint i)
 {
     interface_options *interface_opts;
@@ -555,81 +555,39 @@ get_iface_list_string(capture_options *capture_opts, guint32 style)
 #ifdef _WIN32
     if (capture_opts->ifaces->len < 2) {
 #else
-        if (capture_opts->ifaces->len < 4) {
+    if (capture_opts->ifaces->len < 4) {
 #endif
-            for (i = 0; i < capture_opts->ifaces->len; i++) {
-                if (i > 0) {
-                    if (capture_opts->ifaces->len > 2) {
-                        g_string_append_printf(iface_list_string, ",");
-                    }
-                    g_string_append_printf(iface_list_string, " ");
-                    if (i == capture_opts->ifaces->len - 1) {
-                        g_string_append_printf(iface_list_string, "and ");
-                    }
+        for (i = 0; i < capture_opts->ifaces->len; i++) {
+            if (i > 0) {
+                if (capture_opts->ifaces->len > 2) {
+                    g_string_append_printf(iface_list_string, ",");
                 }
-                if (style & IFLIST_QUOTE_IF_DESCRIPTION)
-                    g_string_append_printf(iface_list_string, "'");
-                g_string_append_printf(iface_list_string, "%s", get_iface_description_for_interface(capture_opts, i));
-                if (style & IFLIST_QUOTE_IF_DESCRIPTION)
-                    g_string_append_printf(iface_list_string, "'");
-                if (style & IFLIST_SHOW_FILTER) {
-                    interface_options *interface_opts;
+                g_string_append_printf(iface_list_string, " ");
+                if (i == capture_opts->ifaces->len - 1) {
+                    g_string_append_printf(iface_list_string, "and ");
+                }
+            }
+            if (style & IFLIST_QUOTE_IF_DESCRIPTION)
+                g_string_append_printf(iface_list_string, "'");
+            const gchar* name = get_iface_description_for_interface(capture_opts, i);
+            g_string_append_printf(iface_list_string, "%s", name ? name : "");
+            if (style & IFLIST_QUOTE_IF_DESCRIPTION)
+                g_string_append_printf(iface_list_string, "'");
+            if (style & IFLIST_SHOW_FILTER) {
+                interface_options *interface_opts;
 
-                    interface_opts = &g_array_index(capture_opts->ifaces, interface_options, i);
-                    if (interface_opts->cfilter != NULL &&
-                            strlen(interface_opts->cfilter) > 0) {
-                        g_string_append_printf(iface_list_string, " (%s)", interface_opts->cfilter);
-                    }
+                interface_opts = &g_array_index(capture_opts->ifaces, interface_options, i);
+                if (interface_opts->cfilter != NULL &&
+                        strlen(interface_opts->cfilter) > 0) {
+                    g_string_append_printf(iface_list_string, " (%s)", interface_opts->cfilter);
                 }
             }
-        } else {
-            g_string_append_printf(iface_list_string, "%u interfaces", capture_opts->ifaces->len);
         }
-        return iface_list_string;
+    } else {
+        g_string_append_printf(iface_list_string, "%u interfaces", capture_opts->ifaces->len);
+    }
+    return iface_list_string;
 }
-
-gchar *
-get_iface_display_name(const gchar *description, const if_info_t *if_info)
-{
-    if (description && description[0]) {
-        /* We have a user-supplied description. */
-#ifdef _WIN32
-        gchar *if_string = if_info->friendly_name ? if_info->friendly_name : if_info->name;
-        return g_strdup_printf("%s: %s", description, if_string);
-#else
-        return g_strdup_printf("%s: %s", description, if_info->name);
-#endif
-    }
-
-    if (if_info->friendly_name) {
-        /* We have a friendly name from the OS. */
-#ifdef _WIN32
-        /*
-         * On Windows, if we have a friendly name, just show it,
-         * don't show the name, as that's a string made out of
-         * the device GUID, and not at all friendly.
-         */
-        return g_strdup_printf("%s", if_info->friendly_name);
-#else
-        /*
-         * On UN*X, if we have a friendly name, show it along
-         * with the interface name; the interface name is short
-         * and somewhat friendly, and many UN*X users are used
-         * to interface names, so we should show it.
-         */
-        return g_strdup_printf("%s: %s", if_info->friendly_name, if_info->name);
-#endif
-    }
-
-    if (if_info->vendor_description) {
-        /* We have a device description from libpcap. */
-        return g_strdup_printf("%s: %s", if_info->vendor_description, if_info->name);
-    }
-
-    /* No additional descriptions found. */
-    return g_strdup(if_info->name);
-}
-
 #endif /* HAVE_LIBPCAP */
 
 /*
